@@ -7,12 +7,14 @@ class ITMClient(object):
     """ Client class for Proofpoint ITM SaaS API.
         
     This class shall be initialized with a config dictionary containing the
-    following information:
+    client_id, tenant_id, and client_secret::
+
         {
-            "tenant_id" : "<The tenant name>"
-            "client_id" : "<application client id>"
-            "client_secret": "<client secret for token based auth>"
+            "tenant_id" : "The tenant name"
+            "client_id" : "application client id"
+            "client_secret": "client secret for token based auth"
         }
+    
     """
     
     def __init__(self, config, scope='*', verify=True, **kwargs):
@@ -39,7 +41,7 @@ class ITMClient(object):
 
     
     def get_endpoints(self, includes: str='*', kind: str='*', status: str='*',
-                      headers: dict=None, count: bool=False) -> dict:
+                      headers: dict={}, count: bool=False) -> dict:
         """Gets endpoints from the registry API
 
         Fetches all endpoints of a given kind from the registry api
@@ -67,9 +69,7 @@ class ITMClient(object):
                   'status': status
                  }
 
-        if headers is None:
-            headers = {
-                'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
 
         endpoints = []
         resp = webclient.get_request(
@@ -92,7 +92,7 @@ class ITMClient(object):
         return endpoints
 
 
-    def get_rules(self, includes: str='*', headers: dict=None) -> list:
+    def get_rules(self, includes: str='*', headers: dict={}) -> list:
         """Get all rules 
 
         Query for all rules in the depot API
@@ -110,20 +110,18 @@ class ITMClient(object):
         endpoint = '/v2/apis/ruler/rules'
         url = self.base_url + endpoint
         params = {'includes': includes}
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
-        
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
         resp = webclient.get_request(url, headers=headers, params=params)
         return resp['data']
 
 
-    def get_rule(self, id: str, includes: str='*', headers: dict=None) -> dict:
+    def get_rule(self, id_: str, includes: str='*', headers: dict={}) -> dict:
         """Get rule by ID 
 
         Query for rule by ID in the depot API
 
         Args:
-            id (str):
+            id_ (str):
                 Rule id to return, if not provided, return all
             includes (str):
                 comma-separated list of attributes to include, default = *
@@ -134,23 +132,21 @@ class ITMClient(object):
         Returns: 
             A dict of rule attributes
         """
-        endpoint = f'/v2/apis/ruler/rules/{id}'
+        endpoint = f'/v2/apis/ruler/rules/{id_}'
         url = self.base_url + endpoint
         params = {'includes': includes}
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
-        
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
         resp = webclient.get_request(url, headers=headers, params=params)
         return resp
 
 
-    def update_rule(self, id: str, rule: Rule, headers: dict=None, test: bool=False) -> dict:
+    def update_rule(self, id_: str, rule: Rule, headers: dict={}, test: bool=False) -> dict:
         """Update existing rule
 
         Updates an existing rule from a proofpoint_itm.classes.Rule object
 
         Args:
-            id (str):
+            id_ (str):
                 Rule ID to update
             rule (obj): 
                 proofpoint_itm.classes.Rule object
@@ -165,15 +161,14 @@ class ITMClient(object):
         """
         if test:
             return {'id': str(uuid.uuid4())}
-        endpoint = f'/v2/apis/ruler/rules/{id}'
+        endpoint = f'/v2/apis/ruler/rules/{id_}'
         url = self.base_url + endpoint
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}",}
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}",}
         resp = webclient.post_request(url, headers=headers, json_data=rule.as_dict(), method='PUT')
         return resp
 
 
-    def create_rule(self, rule: Rule, headers=None, test=False):
+    def create_rule(self, rule: Rule, headers: dict={}, test=False):
         """Create new rule
 
         Creates a new rule from a proofpoint_itm.classes.Rule object
@@ -194,16 +189,13 @@ class ITMClient(object):
             return {'id': str(uuid.uuid4())}
         endpoint = f'/v2/apis/ruler/rules'
         url = self.base_url + endpoint
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}",}
-
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}",}
         data = {'data': [rule.as_dict()]}
-
         resp = webclient.post_request(url, headers=headers, json_data=data, method='POST')
         return resp
 
 
-    def get_predicates(self, includes: str='*', headers: dict=None) -> list:
+    def get_predicates(self, includes: str='*', headers: dict={}) -> list:
         """Get all predicates
 
         Query for all predicates in the depot API, does not return built-in
@@ -221,20 +213,18 @@ class ITMClient(object):
         endpoint = '/v2/apis/depot/predicates'
         url = self.base_url + endpoint
         params = {'includes': includes}
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
-        
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
         resp = webclient.get_request(url, headers=headers, params=params)
         return resp['data']
 
 
-    def get_predicate(self, id: str, includes: str='*', headers: dict=None) -> dict:
+    def get_predicate(self, id_: str, includes: str='*', headers: dict={}) -> dict:
         """Query for a single predicate
 
         Query for a single predicate by ID
 
         Args:
-            id (str):
+            id_ (str):
                 The predicate id to return
             includes (str): 
                 Comma-separated list of attributes to include, default = *
@@ -245,17 +235,15 @@ class ITMClient(object):
         Returns:
             A dict of predicate attributes
         """
-        endpoint = f'/v2/apis/depot/predicates/{id}'
+        endpoint = f'/v2/apis/depot/predicates/{id_}'
         url = self.base_url + endpoint
         params = {'includes': includes}
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
-        
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
         resp = webclient.get_request(url, headers=headers, params=params)
         return resp
 
 
-    def get_conditions(self, includes: str='*', headers: dict=None) -> list:
+    def get_conditions(self, includes: str='*', headers: dict={}) -> list:
         """Queries for custom conditions (predicates) created by users
 
         Query for all custom match predicates (user created) that are not auto
@@ -281,11 +269,11 @@ class ITMClient(object):
         return conditions
 
     
-    def update_predicate(self, id, predicate: Predicate, headers=None, test=False):
+    def update_predicate(self, id_, predicate: Predicate, headers: dict={}, test: bool=False) -> dict:
         """Update a predicate by ID
 
         Args:
-            id (str):
+            id_ (str):
                 ID of the predicate to udpate
             data (dict)
                 A dict of the keys/values to update
@@ -298,16 +286,14 @@ class ITMClient(object):
         Returns:
             API response (dict)
         """
-        endpoint = f'/v2/apis/depot/predicates/{id}'
+        endpoint = f'/v2/apis/depot/predicates/{id_}'
         url = self.base_url + endpoint
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}",}
-        
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}",}
         resp = webclient.post_request(url, headers=headers, json_data=predicate.as_dict(), method='PUT')
         return resp
 
 
-    def create_predicate(self, predicate: Predicate, headers: dict=None, test: bool=False) -> dict:
+    def create_predicate(self, predicate: Predicate, headers: dict={}, test: bool=False) -> dict:
         """Create new predicate
 
         Creates a new predicate from a proofpoint_itm.classes.Predicate object
@@ -328,16 +314,14 @@ class ITMClient(object):
             return {'id': str(uuid.uuid4())}
         endpoint = f'/v2/apis/depot/predicates'
         url = self.base_url + endpoint
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}",}
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
 
         data = {'data': [predicate.as_dict()]}
-
         resp = webclient.post_request(url, headers=headers, json_data=data, method='POST')
         return resp
 
 
-    def get_tags(self, includes: str='*', headers: dict=None) -> list:
+    def get_tags(self, includes: str='*', headers: dict={}) -> list:
         """Get all tags
 
         Query for all tags in the depot API, does not return built-in
@@ -355,20 +339,18 @@ class ITMClient(object):
         endpoint = '/v2/apis/depot/tags'
         url = self.base_url + endpoint
         params = {'includes': includes}
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
-        
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
         resp = webclient.get_request(url, headers=headers, params=params)
         return resp['data']
 
 
-    def get_tag(self, id: str, includes: str='*', headers: dict=None) -> dict:
+    def get_tag(self, id_: str, includes: str='*', headers: dict={}) -> dict:
         """Get tag by ID
 
         Query for specific tag ID in the depot API
 
         Args:
-            id (str):
+            id_ (str):
                 The tag ID
             includes (str): 
                 comma-separated list of attributes to include, default = *
@@ -379,22 +361,20 @@ class ITMClient(object):
         Returns: 
             A dict of tags info (dict)
         """
-        endpoint = f'/v2/apis/depot/tags/{id}'
+        endpoint = f'/v2/apis/depot/tags/{id_}'
         url = self.base_url + endpoint
         params = {'includes': includes}
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
-        
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
         resp = webclient.get_request(url, headers=headers, params=params)
         return resp
 
-    def update_tag(self, id: str, tag: Tag, headers: dict=None, test: bool=False) -> dict:
+    def update_tag(self, id_: str, tag: Tag, headers: dict={}, test: bool=False) -> dict:
         """Update existing tag
 
         Update existing tag from a proofpoint_itm.classes.Tag object
 
         Args:
-            id (str):
+            id_ (str):
                 id of the target tag to update
             tag (obj):
                 proofpoint_itm.classes.Tag object
@@ -409,15 +389,13 @@ class ITMClient(object):
         """
         if test:
             return {'id': str(uuid.uuid4())}
-        endpoint = f'/v2/apis/depot/tags/{id}'
+        endpoint = f'/v2/apis/depot/tags/{id_}'
         url = self.base_url + endpoint
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}",}
-
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}",}
         resp = webclient.post_request(url, headers=headers, json_data=tag.as_dict(), method='PATCH')
         return resp
 
-    def create_tag(self, tag: Tag, headers: dict=None, test: bool=False) -> dict:
+    def create_tag(self, tag: Tag, headers: dict={}, test: bool=False) -> dict:
         """Create new tag
 
         Creates a new tag from a proofpoint_itm.classes.Tag object
@@ -438,44 +416,38 @@ class ITMClient(object):
             return {'id': str(uuid.uuid4())}
         endpoint = f'/v2/apis/depot/tags'
         url = self.base_url + endpoint
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}",}
-
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}",}
         resp = webclient.post_request(url, headers=headers, json_data=tag.as_dict(), method='POST')
         return resp
 
 
-    def get_agent_policies(self, includes: str='*', headers: dict=None, params: dict=None) -> dict:
+    def get_agent_policies(self, includes: str='*', headers: dict={}, params: dict=None) -> dict:
         endpoint = '/v2/apis/registry/policies'
         url = self.base_url + endpoint
         if params is None:
             params = {'limit': 99, 'offset': 0, 'includes': includes}
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
-        
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
         resp = webclient.get_request(url, headers=headers, params=params)
         return resp['data']
 
 
-    def get_agent_policy(self, id: str, includes: str='*', headers: dict=None, params: dict=None) -> dict:
-        endpoint = f'/v2/apis/registry/policies/{id}'
+    def get_agent_policy(self, id_: str, includes: str='*', headers: dict={}, params: dict=None) -> dict:
+        endpoint = f'/v2/apis/registry/policies/{id_}'
         url = self.base_url + endpoint
         if params is None:
             params = {'limit': 99, 'offset': 0, 'includes': includes}
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
-        
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
         resp = webclient.get_request(url, headers=headers, params=params)
         return resp['data']
 
 
-    def update_agent_policy(self, id, policy: AgentPolicy, headers: dict=None, test: bool=False) -> dict:
+    def update_agent_policy(self, id_, policy: AgentPolicy, headers: dict={}, test: bool=False) -> dict:
         """Update an Agent Policy by ID
 
         Update an agent policy
         
         Args:
-            id (str):
+            id_ (str):
                 ID of the policy to update
             policy (AgentPolicy):
                 A proofpoint_itm.classes.AgentPolicy object
@@ -490,21 +462,19 @@ class ITMClient(object):
         """
         if test:
             return {'status': 200, 'msg': 'success'}
-        endpoint = f'/v2/apis/registry/policies/{id}'
+        endpoint = f'/v2/apis/registry/policies/{id_}'
         url = self.base_url + endpoint
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
-        
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
         resp = webclient.post_request(url, headers=headers, json_data=policy.as_dict(), method='PATCH')
         return resp
 
-    def overwrite_agent_policy(self, id, policy: AgentPolicy, headers: dict=None, test: bool=False) -> dict:
+    def overwrite_agent_policy(self, id_, policy: AgentPolicy, headers: dict={}, test: bool=False) -> dict:
         """Overwrite an Agent Policy by ID
 
         Overwrite an agent policy
         
         Args:
-            id (str):
+            id_ (str):
                 ID of the policy to update
             policy (AgentPolicy):
                 A proofpoint_itm.classes.AgentPolicy object
@@ -519,15 +489,13 @@ class ITMClient(object):
         """
         if test:
             return {'status': 200, 'msg': 'success'}
-        endpoint = f'/v2/apis/registry/policies/{id}'
+        endpoint = f'/v2/apis/registry/policies/{id_}'
         url = self.base_url + endpoint
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
-        
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
         resp = webclient.post_request(url, headers=headers, json_data=policy.as_dict(), method='PUT')
         return resp
 
-    def create_agent_policy(self, policy: AgentPolicy, headers: dict=None, test: bool=False) -> dict:
+    def create_agent_policy(self, policy: AgentPolicy, headers: dict={}, test: bool=False) -> dict:
         """Create an Agent Policy
 
         Create an new agent policy from a proofpoint_itm.classes.AgentPolicy object
@@ -548,14 +516,12 @@ class ITMClient(object):
             return {'status': 200, 'msg': 'success'}
         endpoint = f'/v2/apis/registry/policies'
         url = self.base_url + endpoint
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
-        
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
         resp = webclient.post_request(url, headers=headers, json_data=policy.as_dict(), method='POST')
         return resp
 
 
-    def get_notification_policies(self, includes='*', headers=None):
+    def get_notification_policies(self, includes='*', headers={}):
         """Get all notification policies
 
         Query for all notification policies in the notifications API
@@ -573,20 +539,18 @@ class ITMClient(object):
         endpoint = '/v2/apis/notification/target-groups'
         url = self.base_url + endpoint
         params = {'includes': includes}
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
-        
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
         resp = webclient.get_request(url, headers=headers, params=params)
         return resp['data']
 
 
-    def update_notification_policy(self, id: str, target_group: TargetGroup, headers: dict=None, test: bool=False) -> dict:
+    def update_notification_policy(self, id_: str, target_group: TargetGroup, headers: dict={}, test: bool=False) -> dict:
         """Update existing notification policy (target-group)
 
         Updates an existing notification policy from a proofpoint_itm.classes.TargetGroup object
 
         Args:
-            id (str)
+            id_ (str)
                 The target-group ID to update
             target_group (obj):
                 proofpoint_itm.classes.TargetGroup object
@@ -601,16 +565,14 @@ class ITMClient(object):
         """
         if test:
             return {'id': str(uuid.uuid4())}
-        endpoint = f'/v2/apis/notification/target-groups/{id}'
+        endpoint = f'/v2/apis/notification/target-groups/{id_}'
         url = self.base_url + endpoint
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}",}
-
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}",}
         resp = webclient.post_request(url, headers=headers, json_data=target_group.as_dict(), method='PATCH')
         return resp
 
 
-    def create_notification_policy(self, target_group: TargetGroup, headers: dict=None, test: bool=False) -> dict:
+    def create_notification_policy(self, target_group: TargetGroup, headers: dict={}, test: bool=False) -> dict:
         """Create new notification policy (target-group)
 
         Creates a new notification policy from a proofpoint_itm.classes.TargetGroup object
@@ -631,15 +593,12 @@ class ITMClient(object):
             return {'id': str(uuid.uuid4())}
         endpoint = '/v2/apis/notification/target-groups'
         url = self.base_url + endpoint
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}",}
-
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}",}
         data = [target_group.as_dict()]
-
         resp = webclient.post_request(url, headers=headers, json_data=data, method='POST')
         return resp
 
-    def get_dictionaries(self, headers: dict=None, includes: str='*') -> dict:
+    def get_dictionaries(self, headers: dict={}, includes: str='*') -> dict:
         """
         Queries for user defined dictionaries
 
@@ -648,54 +607,48 @@ class ITMClient(object):
         endpoint = '/v2/apis/ruler/configurations/dlp/dictionaries'
         url = self.base_url + endpoint
         params = {'includes': includes}
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
-        
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
         resp = webclient.get_request(url, headers=headers, params=params)
         return resp['data']
 
 
-    def get_dictionary(self, id: str, headers: dict=None, include: str=None) -> dict:
+    def get_dictionary(self, id_: str, headers: dict={}, include: str=None) -> dict:
         """
         Queries for user defined dictionaries
 
         Returns json as dict
         """
-        endpoint = f'/v2/apis/ruler/configurations/dlp/dictionaries/{id}'
+        endpoint = f'/v2/apis/ruler/configurations/dlp/dictionaries/{id_}'
         url = self.base_url + endpoint
         params = {}
         if include is not None:
             params['include'] = include
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
-        
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
         resp = webclient.get_request(url, headers=headers, params=params)
         return resp['data']
 
 
-    def get_dictionary_terms(self, id: str, headers: dict=None, includes: str='*') -> dict:
+    def get_dictionary_terms(self, id_: str, headers: dict={}, includes: str='*') -> dict:
         """
         Queries for entries/terms in specific user defined dictionary
 
         Returns dict dictionary entries
         """
-        endpoint = f'/v2/apis/ruler/configurations/dlp/dictionaries/{id}/entries'
+        endpoint = f'/v2/apis/ruler/configurations/dlp/dictionaries/{id_}/entries'
         url = self.base_url + endpoint
         params = {'includes': includes}
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
-        
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
         resp = webclient.get_request(url, headers=headers, params=params)
         return resp['data']
     
 
-    def update_dictionary(self, id: str, dictionary: Dictionary, headers: dict=None) -> dict:
+    def update_dictionary(self, id_: str, dictionary: Dictionary, headers: dict={}) -> dict:
         """Update existing dictionary
 
         Updates an existing user defined dictionary by ID
 
         Args:
-            id (str):
+            id_ (str):
                 dictionary ID
             dictionary (Dictionary):
                 A proofpoint_itm.classes.Dictionary object
@@ -706,16 +659,14 @@ class ITMClient(object):
         Returns:
             API Response as dict
         """
-        endpoint = f'/v2/apis/ruler/configurations/dlp/dictionaries/{id}'
+        endpoint = f'/v2/apis/ruler/configurations/dlp/dictionaries/{id_}'
         url = self.base_url + endpoint
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}",}
-        
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}",}
         resp = webclient.post_request(url, headers=headers, json_data=dictionary.as_dict(), method='PATCH')
         return resp
 
 
-    def create_dictionary(self, dictionary: Dictionary, headers: dict=None) -> dict:
+    def create_dictionary(self, dictionary: Dictionary, headers: dict={}) -> dict:
         """Create new dictionary
         
         Creates a new user defined dictionary
@@ -732,13 +683,11 @@ class ITMClient(object):
         """
         endpoint = '/v2/apis/ruler/configurations/dlp/dictionaries'
         url = self.base_url + endpoint
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
-        
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
         resp = webclient.post_request(url, headers=headers, json_data=dictionary.as_dict(), method='POST')
         return resp
 
-    def create_dictionaries(self, dictionaries: list=[], headers: dict=None):
+    def create_dictionaries(self, dictionaries: list=[], headers: dict={}):
         """
         Creates or updates a batch list of dictionaries
 
@@ -754,25 +703,22 @@ class ITMClient(object):
         """
         endpoint = '/v2/apis/ruler/configurations/dlp/dictionaries'
         url = self.base_url + endpoint
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
         dictionary_list = [d.as_dict() for d in dictionaries]
         data = { 'data': dictionary_list }
         resp = webclient.post_request(url, headers=headers, json_data=data, method='PATCH')
         return resp
 
 
-    def delete_dictionary(self, id: str, headers: dict=None) -> dict:
+    def delete_dictionary(self, id_: str, headers: dict={}) -> dict:
         """
         Deletes a dictionary by ID
 
         Returns response as dict
         """
-        endpoint = f'/v2/apis/ruler/configurations/dlp/dictionaries/{id}'
+        endpoint = f'/v2/apis/ruler/configurations/dlp/dictionaries/{id_}'
         url = self.base_url + endpoint
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
-        
+        headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
         resp = webclient.delete_request(url, headers=headers)
         return resp
 
@@ -781,28 +727,24 @@ class ITMClient(object):
         """Update workflow status of an alert/incident
         
         Args:
-            fqid (str):
+            fqid_ (str):
                 The fqid of an event/incident
             status (str):
                 The new status to be applied to the incident
                 Accepts new, reopened, in-progress, escalated, on-hold,
-                        resolved, false-positive, not-an-issue
+                resolved, false-positive, not-an-issue
 
         Returns:
             urllib.response object
         """
         endpoint = f'/v2/apis/activity/events/{fqid}/annotations/workflow'
         url = self.base_url + endpoint
-
         data = {
             'state': {
                 'status': f'incident:status:{status}'
             }
         }
-
-        if headers is None:
-            headers = {'Authorization': f"{self.auth.token['token_type']} {self.auth.access_token}"}
-
+        headers['Authorization'] = f"{self.auth.token['token_type']} {self.auth.access_token}"
         resp = webclient.post_request(url, headers=headers, json_data=data, method='PATCH')
         return resp
 
@@ -814,15 +756,15 @@ class ITMClient(object):
         resp = webclient.get_request(url, headers=headers)
         return resp['data']
 
-    def get_detector(self, id: str, headers: dict={}) -> dict:
-        endpoint = f'/v2/apis/ruler/configurations/dlp/detectors/{id}'
+    def get_detector(self, id_: str, headers: dict={}) -> dict:
+        endpoint = f'/v2/apis/ruler/configurations/dlp/detectors/{id_}'
         url = self.base_url + endpoint
         headers['Authorization'] = f"{self.auth.token['token_type']} {self.auth.access_token}"
         resp = webclient.get_request(url, headers=headers)
         return resp
 
-    def update_detector(self, id: str, detector: Detector, headers: dict={}):
-        endpoint = f'/v2/apis/ruler/configurations/dlp/detectors/{id}'
+    def update_detector(self, id_: str, detector: Detector, headers: dict={}):
+        endpoint = f'/v2/apis/ruler/configurations/dlp/detectors/{id_}'
         url = self.base_url + endpoint
         headers['Authorization'] = f"{self.auth.token['token_type']} {self.auth.access_token}"
         resp = webclient.post_request(url, headers=headers, json_data=detector.as_dict(), method='PATCH')
@@ -842,15 +784,15 @@ class ITMClient(object):
         resp = webclient.get_request(url, headers=headers)
         return resp['data']
 
-    def get_detector_set(self, id: str, headers: dict={}) -> dict:
-        endpoint = f'/v2/apis/ruler/configurations/dlp/detectorsets/{id}'
+    def get_detector_set(self, id_: str, headers: dict={}) -> dict:
+        endpoint = f'/v2/apis/ruler/configurations/dlp/detectorsets/{id_}'
         url = self.base_url + endpoint
         headers['Authorization'] = f"{self.auth.token['token_type']} {self.auth.access_token}"
         resp = webclient.get_request(url, headers=headers)
         return resp
 
-    def update_detector_set(self, id: str, detector_set: DetectorSet, headers: dict={}):
-        endpoint = f'/v2/apis/ruler/configurations/dlp/detectorsets/{id}'
+    def update_detector_set(self, id_: str, detector_set: DetectorSet, headers: dict={}):
+        endpoint = f'/v2/apis/ruler/configurations/dlp/detectorsets/{id_}'
         url = self.base_url + endpoint
         headers['Authorization'] = f"{self.auth.token['token_type']} {self.auth.access_token}"
         resp = webclient.post_request(url, headers=headers, json_data=detector_set.as_dict(), method='PATCH')
@@ -863,8 +805,8 @@ class ITMClient(object):
         resp = webclient.post_request(url, headers=headers, json_data=detector_set.as_dict(), method='POST')
         return resp
     
-    def delete_detector_set(self, id: str, headers: dict={}):
-        endpoint = f'/v2/apis/ruler/configurations/dlp/detectorsets/{id}'
+    def delete_detector_set(self, id_: str, headers: dict={}):
+        endpoint = f'/v2/apis/ruler/configurations/dlp/detectorsets/{id_}'
         url = self.base_url + endpoint
         headers['Authorization'] = f"{self.auth.token['token_type']} {self.auth.access_token}"
         resp = webclient.delete_request(url, headers=headers)
@@ -890,7 +832,7 @@ class ITMClient(object):
 
         Args:
             query (dict):
-                A dict representing an Elastic Search query, will be converted to json string
+                A dict representing an Elasticsearch query, will be converted to json string
             entity (str):
                 entityTypes to search for
                 Accepted values: list, predicate, tag, article
@@ -910,7 +852,7 @@ class ITMClient(object):
         params['entityTypes'] = entity
         headers['Authorization'] = f"{self.auth.token['token_type']} {self.auth.access_token}"
         resp = webclient.post_request(url, headers=headers, json_data=query, method='POST', params=params)
-        return resp['data']
+        return resp
 
     def notification_search(self, query: dict, entity: str, params: dict={}, headers: dict={}) -> dict:
         """
@@ -918,7 +860,7 @@ class ITMClient(object):
 
         Args:
             query (dict):
-                A dict representing an Elastic Search query, will be converted to json string
+                A dict representing an Elasticsearch query, will be converted to json string
             entity (str):
                 entityTypes to search for
                 Accepted values: target-group, notification
@@ -938,7 +880,7 @@ class ITMClient(object):
         params['entityTypes'] = entity
         headers['Authorization'] = f"{self.auth.token['token_type']} {self.auth.access_token}"
         resp = webclient.post_request(url, headers=headers, json_data=query, method='POST', params=params)
-        return resp['data']
+        return resp
 
     def ruler_search(self, query: str, entity: str, params: dict={}, headers: dict={}) -> dict:
         """
@@ -946,7 +888,7 @@ class ITMClient(object):
 
         Args:
             query (dict):
-                A dict representing an Elastic Search query, will be converted to json string
+                A dict representing an Elasticsearch query, will be converted to json string
             entity (str):
                 entityTypes to search for
                 Accepted values: artifact, rule, rulechain
@@ -966,7 +908,7 @@ class ITMClient(object):
         params['entityTypes'] = entity
         headers['Authorization'] = f"{self.auth.token['token_type']} {self.auth.access_token}"
         resp = webclient.post_request(url, headers=headers, json_data=query, method='POST', params=params)
-        return resp['data']
+        return resp
 
     def activity_search(self, query: dict, entity: str, params: dict={}, headers: dict={}) -> dict:
         """
@@ -974,7 +916,7 @@ class ITMClient(object):
 
         Args:
             query (dict):
-                A dict representing an Elastic Search query, will be converted to json string
+                A dict representing an Elasticsearch query, will be converted to json string
             entity (str):
                 entityTypes to search for
                 Accepted values: event, casbevent, audit, network
@@ -986,7 +928,7 @@ class ITMClient(object):
                 a default header will be created with auth info
 
         Returns:
-            dict of returned objects
+            urllib.response object (dict)
 
         """
         endpoint = '/v2/apis/activity/queries'
@@ -994,4 +936,37 @@ class ITMClient(object):
         params['entityTypes'] = entity
         headers['Authorization'] = f"{self.auth.token['token_type']} {self.auth.access_token}"
         resp = webclient.post_request(url, headers=headers, json_data=query, method='POST', params=params)
-        return resp['data']
\ No newline at end of file
+        return resp
+    
+    def registry_search(self, query: dict, entity: str, params: dict = None, headers: dict = None ) -> dict:
+        """
+        Performs a search query against the registry API
+
+        Args:
+            query (dict):
+                A dict representing an Elasticsearch query, will be converted to json string
+            entity (str):
+                entityTypes to search for
+                Accepted values: event, casbevent, audit, network
+            params (dict):
+                A dict of web request url parameters
+                ex. offset=0, limit=500
+            headers (dict):
+                Headers to include in the http request, if not provided
+                a default header will be created with auth info
+
+        Returns:
+            urllib.response object (dict)
+
+        """
+        url = self.base_url + '/v2/apis/registry/queries'
+        if params is None:
+            params = {}
+        params['entityTypes'] = entity
+
+        if headers is None:
+            headers = {}
+        headers['Authorization'] = f"{self.auth.token['token_type']} {self.auth.access_token}"
+
+        resp = webclient.post_request(url, headers=headers, json_data=query, method='POST', params=params)
+        return resp
\ No newline at end of file
